==> jc-1.4.0.tar.gz: gnu/xml/xpath/Test.h <==
// public abstract class gnu.xml.xpath.Test

// class file dependencies
// @dep_class d99963ba20fa6197 gnu_xml_xpath_Test
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_xpath_Test_H_
#define _JC_gnu_xml_xpath_Test_H_

// Forward structure declarations
struct _jc_gnu_xml_xpath_Test$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_Test$sub_refs	_jc_gnu_xml_xpath_Test$sub_refs;
typedef struct _jc_gnu_xml_xpath_Test$sub_nonrefs	_jc_gnu_xml_xpath_Test$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_Test$refs	_jc_gnu_xml_xpath_Test$refs;
typedef struct _jc_gnu_xml_xpath_Test$nonrefs	_jc_gnu_xml_xpath_Test$nonrefs;
typedef struct _jc_gnu_xml_xpath_Test$object	_jc_gnu_xml_xpath_Test$object;

typedef const struct _jc_gnu_xml_xpath_Test$vmethods	_jc_gnu_xml_xpath_Test$vmethods;
typedef const struct _jc_gnu_xml_xpath_Test$vtable	_jc_gnu_xml_xpath_Test$vtable;
typedef const struct _jc_gnu_xml_xpath_Test$vtype	_jc_gnu_xml_xpath_Test$vtype;

// Constructors
extern void _jc_gnu_xml_xpath_Test$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_xpath_Test$object *);

// Virtual methods
extern struct _jc_gnu_xml_xpath_Test$object *_jc_gnu_xml_xpath_Test$method$clone$73a8d2a4d673dd95(_jc_env *, struct _jc_gnu_xml_xpath_Test$object *, struct _jc_java_lang_Object$object *);
extern jboolean _jc_gnu_xml_xpath_Test$method$matches$528a77e426fd27f8(_jc_env *, struct _jc_gnu_xml_xpath_Test$object *, struct _jc_object *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_xpath_Test$method_info$clone$73a8d2a4d673dd95;
extern _jc_method _jc_gnu_xml_xpath_Test$method_info$matches$528a77e426fd27f8;

// Virtual methods structure
struct _jc_gnu_xml_xpath_Test$vmethods {
	struct _jc_gnu_xml_xpath_Test$object	*(*clone$73a8d2a4d673dd95)(_jc_env *, struct _jc_gnu_xml_xpath_Test$object *, struct _jc_java_lang_Object$object *);
	jboolean	(*matches$528a77e426fd27f8)(_jc_env *, struct _jc_gnu_xml_xpath_Test$object *, struct _jc_object *, jint, jint);
};

// Vtable
struct _jc_gnu_xml_xpath_Test$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_Test$vmethods	gnu_xml_xpath_Test;
};

// Vtype
struct _jc_gnu_xml_xpath_Test$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_Test$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_Test$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_Test$refs {
    _jc_gnu_xml_xpath_Test$sub_refs	gnu_xml_xpath_Test;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_Test$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_Test$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_Test$sub_nonrefs	gnu_xml_xpath_Test;
};

// Object instance structure
struct _jc_gnu_xml_xpath_Test$object {
	_jc_gnu_xml_xpath_Test$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_Test$vtype	*vtype;
	_jc_gnu_xml_xpath_Test$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_Test$vtype _jc_gnu_xml_xpath_Test$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_Test, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_Test$class_object;

#endif	/* _JC_gnu_xml_xpath_Test_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/xpath/Test.h <==
// public abstract class gnu.xml.xpath.Test

// class file dependencies
// @dep_class d99963ba20fa6197 gnu_xml_xpath_Test
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_xpath_Test_H_
#define _JC_gnu_xml_xpath_Test_H_

// Forward structure declarations
struct _jc_gnu_xml_xpath_Test$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_Test$sub_refs	_jc_gnu_xml_xpath_Test$sub_refs;
typedef struct _jc_gnu_xml_xpath_Test$sub_nonrefs	_jc_gnu_xml_xpath_Test$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_Test$refs	_jc_gnu_xml_xpath_Test$refs;
typedef struct _jc_gnu_xml_xpath_Test$nonrefs	_jc_gnu_xml_xpath_Test$nonrefs;
typedef struct _jc_gnu_xml_xpath_Test$object	_jc_gnu_xml_xpath_Test$object;

typedef const struct _jc_gnu_xml_xpath_Test$vmethods	_jc_gnu_xml_xpath_Test$vmethods;
typedef const struct _jc_gnu_xml_xpath_Test$vtable	_jc_gnu_xml_xpath_Test$vtable;
typedef const struct _jc_gnu_xml_xpath_Test$vtype	_jc_gnu_xml_xpath_Test$vtype;

// Constructors
extern void _jc_gnu_xml_xpath_Test$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_xpath_Test$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_xml_xpath_Test$object *_jc_gnu_xml_xpath_Test$method$clone$73a8d2a4d673dd95(_jc_env *, struct _jc_gnu_xml_xpath_Test$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_xml_xpath_Test$method$matches$528a77e426fd27f8(_jc_env *, struct _jc_gnu_xml_xpath_Test$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_xpath_Test$method_info$clone$73a8d2a4d673dd95;
extern _jc_method _jc_gnu_xml_xpath_Test$method_info$matches$528a77e426fd27f8;

// Virtual methods structure
struct _jc_gnu_xml_xpath_Test$vmethods {
	struct _jc_gnu_xml_xpath_Test$object	*(*clone$73a8d2a4d673dd95)(_jc_env *, struct _jc_gnu_xml_xpath_Test$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jboolean	(*matches$528a77e426fd27f8)(_jc_env *, struct _jc_gnu_xml_xpath_Test$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_xpath_Test$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_Test$vmethods	gnu_xml_xpath_Test;
};

// Vtype
struct _jc_gnu_xml_xpath_Test$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_Test$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_Test$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_Test$refs {
    _jc_gnu_xml_xpath_Test$sub_refs	gnu_xml_xpath_Test;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_Test$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_Test$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_Test$sub_nonrefs	gnu_xml_xpath_Test;
};

// Object instance structure
struct _jc_gnu_xml_xpath_Test$object {
	_jc_gnu_xml_xpath_Test$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_Test$vtype	*vtype;
	_jc_gnu_xml_xpath_Test$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_Test$vtype _jc_gnu_xml_xpath_Test$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_Test, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_Test$class_object;

#endif	/* _JC_gnu_xml_xpath_Test_H_ */
